@@ -1,7 +1,8 @@
+# frozen_string_literal: true
 #
 # Author:: Kurt Yoder (<ktyopscode@yoderhome.com>)
 # Author:: Isa Farnik (<isa@chef.io>)
-# Copyright:: Copyright (c) 2013-2016 Chef Software, Inc.
+# Copyright:: Copyright (c) Chef Software Inc.
 # License:: Apache License, Version 2.0
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,7 +22,7 @@ Ohai.plugin(:Uptime) do
   provides "uptime", "uptime_seconds"
 
   collect_data(:aix) do
-    require "date"
+    require "date" unless defined?(DateTime)
     # below we're going to assume that PID 1 is init (this is true 99.99999% of the time)
     # output will look like this
     # 1148-20:54:50
@@ -30,7 +31,7 @@ Ohai.plugin(:Uptime) do
     so = shell_out("LC_ALL=POSIX ps -o etime= -p 1").stdout.strip
 
     # Here we'll check our shell_out for a dash, which indicates there is a # of days involved
-    # We'll chunk off the days, hours (where applicable), minutes, seconds into seperate vars
+    # We'll chunk off the days, hours (where applicable), minutes, seconds into separate vars
     # We also need to do this because ps -o etime= will not display days if the machine has been up for less than 24 hours
     # If the machine has been up for less than one hour, the shell_out will not output hours hence our else
     # see here: https://www.ibm.com/support/knowledgecenter/en/ssw_aix_72/com.ibm.aix.cmds4/ps.htm#ps__row-d3e109655
@@ -40,9 +41,9 @@ Ohai.plugin(:Uptime) do
     when /^\d+-\d/
       (d, h, m, s) = so.split(/[-:]/)
     when /^\d+:\d+:\d/
-      (h, m, s) = so.split(/[:]/)
+      (h, m, s) = so.split(":")
     else
-      (m, s) = so.split(/[:]/)
+      (m, s) = so.split(":")
     end
     elapsed_seconds = ((d.to_i * 86400) + (h.to_i * 3600) + (m.to_i * 60) + s.to_i)
 
