@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 #
 # Author:: Joerg Herzinger <joerg.herzinger@oiml.at>
 # Author:: Phil Dibowitz <phil@ipom.com>
@@ -18,13 +19,11 @@
 # limitations under the License.
 
 Ohai.plugin(:Lspci) do
-  depends "platform"
   provides "pci"
   optional true
 
   collect_data(:linux) do
     devices = Mash.new
-    lspci = shell_out("lspci -vnnmk")
 
     h = /[0-9a-fA-F]/ # any hex digit
     hh = /#{h}#{h}/ # any 2 hex digits
@@ -46,7 +45,7 @@ Ohai.plugin(:Lspci) do
       end
     end
 
-    lspci.stdout.split("\n").each do |line|
+    shell_out("lspci -vnnmk").stdout.split("\n").each do |line|
       dev = line.scan(/^(.*):\s(.*)$/)[0]
       next if dev.nil?
 
