@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 #
 # License:: Apache License, Version 2.0
 #
@@ -17,7 +18,7 @@ Ohai.plugin(:Memory) do
   provides "memory"
 
   collect_data(:windows) do
-    require "wmi-lite/wmi"
+    require "wmi-lite/wmi" unless defined?(WmiLite::Wmi)
 
     memory Mash.new
     memory[:swap] = Mash.new
